aboutsummaryrefslogtreecommitdiffstats
path: root/packet-ascend.c
diff options
context:
space:
mode:
authorGuy Harris <guy@alum.mit.edu>2001-03-30 06:10:54 +0000
committerGuy Harris <guy@alum.mit.edu>2001-03-30 06:10:54 +0000
commit949888c04a7a85b847da144d14bf51eedb5bad94 (patch)
tree7b517fc86bf7ab944a63d61eb54f9c9c8c11df1c /packet-ascend.c
parente30bc52b6af6cd5975885c4bcd7221d9d9a50650 (diff)
Call the dissector for PPP-in-HDLC-like-framing (RFC 1662) the
"ppp_hdlc" dissector, and call the dissector for "raw" PPP (just RFC 1661, no HDLC encapsulation) the "ppp" dissector. Have the common routine used by both those dissectors take the offset in the tvbuff of the PPP protocol field as an argument, rather than assuming that the protocol field begins at the beginning of the tvbuff, so we don't have to construct a new tvbuff in the PPP-in-HDLC-like-framing dissector. Use the PPP dissector, not the PPP-in-HDLC-like-framing dissector, for PPP over Frame Relay - there's no HDLC header in PPP over Frame Relay, at least according to http://www.cisco.com/univercd/cc/td/doc/product/software/ios120/120newft/120t/120t1/pppframe.htm svn path=/trunk/; revision=3208
Diffstat (limited to 'packet-ascend.c')
-rw-r--r--packet-ascend.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/packet-ascend.c b/packet-ascend.c
index d9f4e23aaf..ce351ce6b2 100644
--- a/packet-ascend.c
+++ b/packet-ascend.c
@@ -1,7 +1,7 @@
/* packet-ascend.c
* Routines for decoding Lucent/Ascend packet traces
*
- * $Id: packet-ascend.c,v 1.24 2001/01/25 06:14:13 guy Exp $
+ * $Id: packet-ascend.c,v 1.25 2001/03/30 06:10:54 guy Exp $
*
* Ethereal - Network traffic analyzer
* By Gerald Combs <gerald@zing.org>
@@ -50,7 +50,7 @@ static const value_string encaps_vals[] = {
{0, NULL } };
static dissector_handle_t eth_handle;
-static dissector_handle_t ppp_handle;
+static dissector_handle_t ppp_hdlc_handle;
static void
dissect_ascend(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
@@ -97,7 +97,7 @@ dissect_ascend(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
switch (pseudo_header->ascend.type) {
case ASCEND_PFX_WDS_X:
case ASCEND_PFX_WDS_R:
- call_dissector(ppp_handle, tvb, pinfo, tree);
+ call_dissector(ppp_hdlc_handle, tvb, pinfo, tree);
break;
case ASCEND_PFX_WDD:
call_dissector(eth_handle, tvb, pinfo, tree);
@@ -149,9 +149,9 @@ void
proto_reg_handoff_ascend(void)
{
/*
* Get handles for the Ethernet and PPP dissectors.
*/
eth_handle = find_dissector("eth");
- ppp_handle = find_dissector("ppp");
+ ppp_hdlc_handle = find_dissector("ppp_hdlc");
dissector_add("wtap_encap", WTAP_ENCAP_ASCEND, dissect_ascend, proto_ascend);
}
@@ -149,9 +149,9 @@ void
{
/*
- * Get handles for the Ethernet and PPP dissectors.
+ * Get handles for the Ethernet and PPP-in-HDLC-like-framing dissectors.
*/
eth_handle = find_dissector("eth");